@@ -7,6 +7,7 @@
 #include "phonelist.h"
 #include "gnomecard.h"
 #include "canvas.h"
+#include "dnd.h"
 
 #define CANVAS_FONT "-adobe-helvetica-medium-r-*-*-*-120-*-*-p-*-iso8859-1"
 #define ADDR_FONT "-adobe-helvetica-medium-r-*-*-*-100-*-*-p-*-iso8859-1"
@@ -48,6 +49,7 @@ gnomecard_canvas_new(void)
 	gint i;
 
 	canvas = gnomecard_canvas = gnome_canvas_new();
+	configure_source_card_dnd (canvas);
 	gtk_widget_pop_visual();
 	gtk_widget_pop_colormap();
 
@@ -413,10 +415,35 @@ gnomecard_canvas_text_item_set(GnomeCanvasItem *p, gchar *text)
 	gnome_canvas_item_set (p, "text", text, NULL);
 }
 
-void
-gnomecard_clear_canvas(void)
+void gnomecard_clear_canvas(void)
 {
-    g_message("gnomecard_clear_canvas not implemented");
+    gnomecard_canvas_text_item_set(cardname, "");
+		gnomecard_canvas_text_item_set(fullname, "");
+		
+    /* title and organization */
+		gnomecard_canvas_text_item_set(title, "");
+    gnomecard_canvas_text_item_set(org, "");
+		
+    /* email and web site */
+    gnomecard_canvas_text_item_set(email, "");
+		
+		gnomecard_canvas_text_item_set(url, "");
+		
+		gnomecard_canvas_text_item_set(homephone, "");
+		gnomecard_canvas_text_item_set(workphone, "");
+		
+    /* address */
+		gnomecard_canvas_text_item_set(homeaddr.street1, "");
+		gnomecard_canvas_text_item_set(homeaddr.street2, "");
+		gnomecard_canvas_text_item_set(homeaddr.state, "");
+		gnomecard_canvas_text_item_set(homeaddr.country, "");
+		gnomecard_canvas_text_item_set(workaddr.street1, "");
+		gnomecard_canvas_text_item_set(workaddr.street2, "");
+		gnomecard_canvas_text_item_set(workaddr.state, "");
+		gnomecard_canvas_text_item_set(workaddr.country, "");
+		
+		/* memos */
+		gnomecard_canvas_text_item_set(memos, "");
 }
 
 void
