@@ -13,7 +13,6 @@
 
 static VObject *card_convert_to_vobject(Card *crd);
 
-
 typedef struct
 {
 	char c;
@@ -1039,7 +1038,8 @@ card_load (GList *crdlist, char *fname)
 		vobj = nextVObjectInList(vobj);
 		cleanVObject(tmp);
 	}
-		
+
+	cleanVObject (vobj);
 	cleanStrTbl ();
 	return crdlist;
 }
@@ -1387,8 +1387,33 @@ card_convert_to_vobject(Card *crd)
 	return vobj;
 }
 
+char *
+card_to_string (Card *crd)
+{
+	VObject *object;
+	char *data, *ret_val;
+	
+	g_assert (crd != NULL);
+
+	object = card_convert_to_vobject (crd);
+	data = writeMemVObject (0, 0, object);
+        ret_val = g_strdup (data);
+	free (data);
+		
+	cleanVObject (object);
+
+	return ret_val;
+}
+
 void 
 card_save(Card *crd, FILE *fp)
 {
-	writeVObject(fp, card_convert_to_vobject(crd));
+	VObject *object;
+	
+	g_return_if_fail (crd != NULL);
+
+	object = card_convert_to_vobject(crd);
+	writeVObject(fp, object);
+	cleanVObject (object);
 }
+
